@@ -4,7 +4,7 @@
 """
 from dipbot import scraper, app
 import click
-from dipbot import app, bot
+from dipbot import app, bot, utilities
 from dipbot.data_definitions import DipGame
 
 
@@ -14,20 +14,16 @@ def cli():
 
 
 @cli.command()
-def report():
-    game_id = app.get_env_var_checked(app.WEBDIP_ID_ENV_VAR_NAME)
-    try:
-        assert game_id != False
-    except:
-        exit(1)
-    dipgame = scraper.get_dipgame_checked(game_id)
+@click.option("-v", "--verbose", is_flag=True, help="prints verbose output")
+def report(verbose):
+    dipgame = scraper.get_dipgame_checked(app.get_game_id())
     try:
         assert dipgame != False
     except:
         click.echo("exiting...")
         exit(1)
 
-    click.echo(app.announce_overall_game_state(dipgame))
+    click.echo(app.announce_overall_game_state(dipgame, verbose))
 
 
 @cli.command()
