@@ -6,8 +6,10 @@ from typing import NewType, Dict
         'name' -> str
         'year' -> int
         'season' -> str
-        'retreats?' -> bool
+        'phase' -> Phase
         'players' -> [list of Player]
+        'started' -> Union[int, None]
+        'deadline' -> Union[int, None] 
 """
 
 DipGame = NewType("DipGame", Dict)
@@ -27,3 +29,12 @@ Player = NewType("Player", Dict)
 """
 
 Turn = NewType("Turn", str)
+
+""" A Phase is one of:
+ - "diplomacy"
+ - "retreats"
+ - "builds"
+ - "finished"
+"""
+
+Phase = NewType("Phase", str)
